# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing the various textual links.

## 1. Test

Setting up the definitions:

property,

descriptor,

@at-rule,

<type>,

function(foo),

value for property,

value for descriptor,

value for @at-rule,

value for <type>,

value named "property",

different-value,

!bang,

!!double-bang,

`Interface`,

`attribute`,

`method()`,

`Dictionary`,

`attribute for Interface`,

`attribute for Dictionary`

`element`

`attribute`

`elements-can-have-dashes-too`

`attribute-with-dashes-because-attributes-can-have-dashes`

`value`

`val with spaces`

`another value`

dfn

AbstractOp

Linking:

property

property

property

property: foo

descriptor

descriptor

@at-rule

<type>

<'property'>

<'descriptor'>

<@at-rule>

<'descriptor'>

<function()>

value

value

property

value

value

different-value

!bang

!!double-bang

!!double-bang

@at-rule

<type>

function()

function()

`Interface`

`attribute`

`attribute`

`method()`

`method()`

`Dictionary`

`ambiguous-attr`

`ambiguous-attr`

`ambiguous-attr`

`ambiguous-attr`

`attribute` `attribute`

descriptor descriptor

value value

`element`

`<element>`

`attribute`

`<element attribute="">`

`attribute-with-dashes-because-attributes-can-have-dashes`

`elements-can-have-dashes-too`

`value`

`-attr value-`

`"val with spaces"`

`another value`

dfn

AbstractOp

Escapes:

'not-a-property'

{{NotWebIDL}}

<{notElement}>

[=not dfn=]

[$NotAbstract$]

## Index

### Terms defined by this specification

- AbstractOp, in §1
- ambiguous-attr
  - attribute for Interface, in §1
  - dict-member for Dictionary, in §1
- another value, in §1
- @at-rule, in §1
- attribute
  - attribute for Interface, in §1
  - element-attr for element, in §1
- attribute-with-dashes-because-attributes-can-have-dashes, in §1
- !bang, in §1
- descriptor, in §1
- dfn, in §1
- Dictionary, in §1
- different-value, in §1
- !!double-bang, in §1
- element, in §1
- elements-can-have-dashes-too, in §1
- function(), in §1
- Interface, in §1
- method(), in §1
- property
  - (property), in §1
  - value for property, in §1
- <type>, in §1
- value
  - attr-value for element/attribute, in §1
  - value for <type>, in §1
  - value for @at-rule, in §1
  - value for @at-rule/descriptor, in §1
  - value for property, in §1
- val with spaces, in §1

#propdef-property Referenced in:

- 1. Test (2) (3) (4) (5)

#descdef-at-rule-descriptor Referenced in:

- 1. Test (2) (3) (4) (5) (6)

#at-ruledef-at-rule Referenced in:

- 1. Test (2) (3)

#typedef-type Referenced in:

- 1. Test (2)

#funcdef-function Referenced in:

- 1. Test (2) (3)

#property-value Referenced in:

- 1. Test (2) (3)

#descriptor-value Referenced in:

- 1. Test (2)

#type-value Referenced in:

- 1. Test

#valdef-property-property Referenced in:

- 1. Test

#valdef-property-different-value Referenced in:

- 1. Test

#valdef-property-bang Referenced in:

- 1. Test

#valdef-property-double-bang Referenced in:

- 1. Test

#interface Referenced in:

- 1. Test

#dom-interface-attribute Referenced in:

- 1. Test (2) (3) (4)

#dom-interface-method Referenced in:

- 1. Test (2)

#dictdef-dictionary Referenced in:

- 1. Test

#interface-attr Referenced in:

- 1. Test (2)

#dict-attr Referenced in:

- 1. Test (2)

#elementdef-element Referenced in:

- 1. Test (2)

#element-attrdef-element-attribute Referenced in:

- 1. Test (2)

#elementdef-elements-can-have-dashes-too Referenced in:

- 1. Test

#element-attrdef-element-attribute-with-dashes-because-attributes-can-have-dashes Referenced in:

- 1. Test

#attr-valuedef-element-attribute-value Referenced in:

- 1. Test (2)

#attr-valuedef-element-attribute-val-with-spaces Referenced in:

- 1. Test

#attr-valuedef-elements-can-have-dashes-too-attribute-with-dashes-because-attributes-can-have-dashes-another-value Referenced in:

- 1. Test

#dfn Referenced in:

- 1. Test

#abstract-opdef-abstractop Referenced in:

- 1. Test